PhysAddr

Struct PhysAddr 

#[repr(transparent)]
pub struct PhysAddr(u64);
A type representing physical addresses in the CPU’s physical address space

Tuple Fields

0: u64

Implementations

Source

impl PhysAddr

pub const fn new(addr: u64) -> Self

Creates a new PhysAddr from a raw u64 address

pub const fn null() -> Self

Creates a new PhysAddr which points to 0

pub fn as_u64(self) -> u64

Returns the address as a u64

pub fn as_usize(self) -> usize

Returns the address as a usize

pub fn as_ptr<T>(self) -> *const T

Returns the address as a *const T pointer

pub fn as_mut_ptr<T>(self) -> *mut T

Returns the address as a *mut T pointer

pub fn as_hhdm_ptr<T>(self) -> *const T

Returns the address as a *const T pointer with the HHDM offset added

pub fn as_mut_hhdm_ptr<T>(self) -> *mut T

Returns the address as a *mut T pointer with the HHDM offset added

pub fn align_up(self, align: u64) -> Self

Returns a new address aligned to the next larger address which is aligned to align

Panics

In debug builds if align is not a power of two

pub fn align_down(self, align: u64) -> Self

Returns a new address aligned to the next smaller address which is aligned to align

Panics

In debug builds if align is not a power of two

pub fn is_aligned(self, align: u64) -> bool

Check whether the address is aligned to align

Source

impl PhysAddr

pub fn as_x86_64(self) -> PhysAddr

Returns a [x86_64::PhysAddr] with the same address value