#[repr(transparent)]pub struct PhysAddr(u64);Expand description
A type representing physical addresses in the CPU’s physical address space
Tuple Fields
0: u64Implementations
Sourceimpl PhysAddr
impl PhysAddr
Sourcepub fn as_mut_ptr<T>(self) -> *mut T
pub fn as_mut_ptr<T>(self) -> *mut T
Returns the address as a *mut T pointer
Sourcepub fn as_hhdm_ptr<T>(self) -> *const T
pub fn as_hhdm_ptr<T>(self) -> *const T
Returns the address as a *const T pointer with the HHDM offset added
Sourcepub fn as_mut_hhdm_ptr<T>(self) -> *mut T
pub fn as_mut_hhdm_ptr<T>(self) -> *mut T
Returns the address as a *mut T pointer with the HHDM offset added
Sourcepub fn align_up(self, align: u64) -> Self
pub fn align_up(self, align: u64) -> Self
Returns a new address aligned to the next larger address which is aligned to align
Panics
In debug builds if align is not a power of two
Sourcepub fn align_down(self, align: u64) -> Self
pub fn align_down(self, align: u64) -> Self
Returns a new address aligned to the next smaller address which is aligned to align
Panics
In debug builds if align is not a power of two
Sourcepub fn is_aligned(self, align: u64) -> bool
pub fn is_aligned(self, align: u64) -> bool
Check whether the address is aligned to align